/*
 * This file is part of  signoncrypto-qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation.
 *
 * Contact: Alberto Mardegan <alberto.mardegan@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#include "test.h"

#include <SignOnCrypto/Encryptor>
#include <QtTest/QtTest>

using namespace SignOnCrypto;

const QString boolKey(QString::fromLatin1("booleanValue"));
const QString integerKey(QString::fromLatin1("integerValue"));
const QString byteArrayKey(QString::fromLatin1("byteArrayValue"));
const QString stringKey(QString::fromLatin1("stringValue"));

void Test::initTestCase()
{
}

void Test::cleanupTestCase()
{
}

void Test::sessionDataTest()
{
    Encryptor *coder = new Encryptor;
    QVERIFY(coder != NULL);

    bool boolParam = true;
    qint32 intParam = 111;
    QByteArray byteArrayParam("QByteArray parameter");
    QString stringParam(QString::fromLatin1("QString parameter"));

    QVariantMap originalData;
    originalData.insert(boolKey, boolParam);
    originalData.insert(integerKey, intParam);
    originalData.insert(byteArrayKey, byteArrayParam);
    originalData.insert(stringKey, stringParam);

    for (int i = 0; i < 4; i++)
    {
        QVariantMap encodedData(coder->encodeVariantMap(originalData, 0));
        QVERIFY(coder->status() == Encryptor::Ok);

        QVariantMap decodedData(coder->decodeVariantMap(encodedData, 0));
        QVERIFY(coder->status() == Encryptor::Ok);
        QVERIFY(decodedData == originalData);
    }

    delete coder;
}

void Test::stringTest()
{
    Encryptor *coder = new Encryptor;

    QString orginalString(QString::fromLatin1("Hello Kitty!"));

    for (int i = 0; i < 4; i++)
    {
        QString encodedString(coder->encodeString(orginalString, 0));
        QVERIFY(coder->status() == Encryptor::Ok);

        QString decodedString(coder->decodeString(encodedString, 0));
        QVERIFY(coder->status() == Encryptor::Ok);
        QVERIFY(decodedString == orginalString);
    }

    delete coder;
}

QTEST_APPLESS_MAIN(Test)
